@@ -6,10 +6,14 @@
 ( cd opt/kde/share/doc/HTML/it/kig ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/juk ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/juk ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kpf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kpf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktuberling ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ktuberling ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/amor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/karm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/karm ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdvi ; rm -rf common )
@@ -34,8 +38,12 @@
 ( cd opt/kde/share/doc/HTML/it/kpdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/krdc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/krdc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/krec ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/krec ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/krfb ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/krfb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kscd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kscd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksim ; rm -rf common )
@@ -92,6 +100,8 @@
 ( cd opt/kde/share/doc/HTML/it/kooka ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksame ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ktnef ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksysv ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ktron ; rm -rf common )
@@ -122,10 +132,16 @@
 ( cd opt/kde/share/doc/HTML/it/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kompare ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kontact ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/konsole ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kanagram ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kanagram ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpackage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/lilo-config ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/lilo-config ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/khelpcenter/quickstart ; rm -rf common )
@@ -142,6 +158,8 @@
 ( cd opt/kde/share/doc/HTML/it/ksirtet ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/konquest ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/akregator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/akregator ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kturtle ; rm -rf common )
@@ -154,6 +172,8 @@
 ( cd opt/kde/share/doc/HTML/it/kweather ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kxsldbg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kwifimanager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kwifimanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kmenuedit ; rm -rf common )
@@ -164,110 +184,8 @@
 ( cd opt/kde/share/doc/HTML/it/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license fdl-license )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf qpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf x11-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 1.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/1.png 1.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf xml.dcl )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 2.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/2.png 2.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 3.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/3.png 3.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 4.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/4.png 4.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 5.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/5.png 5.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 6.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/6.png 6.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 7.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/7.png 7.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 8.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/8.png 8.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 9.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/9.png 9.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf headerbg.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf gpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf mainheader.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf grad.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/grad.png grad.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-web.css )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf lgpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf doxygen.css )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf web-doctop.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-default.css )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kmenu.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf footer.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/footer.html footer.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-common.css )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-left.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf appheader.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/appheader.html appheader.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop2.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf shadow.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/shadow.png shadow.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf docheadergears.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-middle.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-right.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1a.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf 10.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/10.png 10.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1b.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf lgpl-license )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf mainfooter.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom1.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom2.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf header.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/header.html header.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom-middle.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf top-left.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/top-left.png top-left.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf gpl-license )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/gpl-license gpl-license )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf bsd-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf web-docbottom.png )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
-( cd opt/kde/share/doc/HTML/it/common ; rm -rf artistic-license.html )
-( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/it/multisynk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/multisynk ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; rm -rf common )
@@ -276,6 +194,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/arts ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keys ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; rm -rf common )
@@ -284,6 +204,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/filetypes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/cache ; rm -rf common )
@@ -302,10 +224,10 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/panel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; rm -rf common )
@@ -316,6 +238,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/background ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol ; rm -rf common )
@@ -324,8 +248,12 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmstyle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlaunch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; rm -rf common )
@@ -336,10 +264,16 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmsmserver ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/screensaver ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/windowmanagement ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmkonsole ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/language ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; rm -rf common )
@@ -348,6 +282,8 @@
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmtaskbar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker-applets ; rm -rf common )
@@ -384,6 +320,8 @@
 ( cd opt/kde/share/doc/HTML/it/kbabel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kamera ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kaudiocreator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kaudiocreator ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kasteroids ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kasteroids ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kbruch ; rm -rf common )
@@ -392,8 +330,6 @@
 ( cd opt/kde/share/doc/HTML/it/keduca ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kgamma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kgamma ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kmessedwords ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kdevelop ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kdevelop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kicker ; rm -rf common )
@@ -410,12 +346,18 @@
 ( cd opt/kde/share/doc/HTML/it/kmplot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/knotes ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/knotes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kpager ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kpager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kopete ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kpilot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kpilot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kpoker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kruler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kruler ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ktalkd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksnake ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksnake ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kspell ; rm -rf common )
@@ -428,8 +370,6 @@
 ( cd opt/kde/share/doc/HTML/it/ktouch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kwrite ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/megami ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/megami ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kreversi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kreversi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/noatun ; rm -rf common )
@@ -442,8 +382,16 @@
 ( cd opt/kde/share/doc/HTML/it/kblackbox ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kcharselect ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/quanta ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/quanta ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/superkaramba ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/superkaramba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/ksmiletris ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/ksmiletris ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kuickshow ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kde_app_devel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kommander ; rm -rf common )
@@ -462,22 +410,28 @@
 ( cd opt/kde/share/doc/HTML/it/klickety ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kfilereplace ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kgeography ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kgeography ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kleopatra ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kleopatra ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kenolaba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kworldclock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/blinken ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/blinken ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/KRegExpEditor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/KRegExpEditor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/ksokoban ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/ksokoban ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kteatime ; ln -sf /opt/kde/share/doc/HTML/it/common common )
-( cd opt/kde/share/doc/HTML/it/kmathtool ; rm -rf common )
-( cd opt/kde/share/doc/HTML/it/kmathtool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
+( cd opt/kde/share/doc/HTML/it/knetworkconf ; rm -rf common )
+( cd opt/kde/share/doc/HTML/it/knetworkconf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/it/common common )
 ( cd opt/kde/share/doc/HTML/it/kinfocenter/pci ; rm -rf common )
